# caty

Nice cat

## Abstract

Shows a readable content of a file.

Like cat, only nicer. :)

## Usage

    caty FILE
    caty FILE FORMAT
    cat FILE | caty_*


## Installation

    $ pip install caty
